@@ -4,26 +4,26 @@
 
 #pragma once
 
-#include <QObject>
 #include <optional>
+
+#include <QObject>
+
 #include "qwayland-wlr-data-control-unstable-v1.h"
 
 class WlrDataControlDeviceIntegration;
 
-class WlrDataControlOfferIntegration :
-    public QObject,
-    public QtWayland::zwlr_data_control_offer_v1
+class WlrDataControlOfferIntegration : public QObject, public QtWayland::zwlr_data_control_offer_v1
 {
     Q_OBJECT
 public:
-    WlrDataControlOfferIntegration(::zwlr_data_control_offer_v1 *object);
-    virtual ~WlrDataControlOfferIntegration() override;
+    explicit WlrDataControlOfferIntegration(::zwlr_data_control_offer_v1 *object);
+    ~WlrDataControlOfferIntegration() override;
 
     QStringList availableMimeTypes() { return m_mimeTypes; }
-    void setAvailableMimeTypes(QStringList mimeTypes) { m_mimeTypes = mimeTypes; }
+    void setAvailableMimeTypes(const QStringList &mimeTypes) { m_mimeTypes = mimeTypes; }
 
 protected:
-    virtual void zwlr_data_control_offer_v1_offer(const QString &mime_type) override {
+    void zwlr_data_control_offer_v1_offer(const QString &mime_type) override {
         Q_EMIT advertiseMimeType(mime_type);
     }
 
