@@ -486,8 +486,8 @@ QPixmap ItemWidget::getIconPixmap(const QIcon &icon, const QSize &size, qreal pi
     //             而且，在有些QIconEngine的实现中，会去调用另一个QIcon::pixmap，导致 pixmapSize 在这种嵌套调用中越来越大
     //             最终会获取到一个是期望大小几倍的图片，由于图片太大，会很快将 QPixmapCache 塞满，导致后面再调用QIcon::pixmap
     //             读取新的图片时无法缓存，非常影响图片绘制性能。此处在获取图片前禁用 Qt::AA_UseHighDpiPixmaps，自行处理图片大小问题
-    bool useHighDpiPixmaps = qApp->testAttribute(Qt::AA_UseHighDpiPixmaps);
-    qApp->setAttribute(Qt::AA_UseHighDpiPixmaps, false);
+    // bool useHighDpiPixmaps = qApp->testAttribute(Qt::AA_UseHighDpiPixmaps);
+    // qApp->setAttribute(Qt::AA_UseHighDpiPixmaps, false);
 
     QSize icon_size = icon.actualSize(size, mode, state);
 
@@ -498,7 +498,7 @@ QPixmap ItemWidget::getIconPixmap(const QIcon &icon, const QSize &size, qreal pi
     QPixmap px = icon.pixmap(pixmapSize, mode, state);
 
     // restore the value
-    qApp->setAttribute(Qt::AA_UseHighDpiPixmaps, useHighDpiPixmaps);
+    // qApp->setAttribute(Qt::AA_UseHighDpiPixmaps, useHighDpiPixmaps);
 
     if (px.width() > icon_size.width() * pixelRatio) {
         px.setDevicePixelRatio(px.width() * 1.0 / qreal(icon_size.width()));
